---
title: <span class="badge object-type-enum"></span> ParcaQueryType
---
# <span class="badge object-type-enum"></span> ParcaQueryType

## Definition

```python
class ParcaQueryType(enum.StrEnum):
    METRICS = "metrics"
    PROFILE = "profile"
    BOTH = "both"
```
